Datatables is used for term and book listings.

Downloaded from

https://datatables.net/download/index

as minified and concatenated js and css files


The items included in the minified files are in the headers, e.g. for the js as at March 2024:

```
/*
 * This combined file was created by the DataTables downloader builder:
 *   https://datatables.net/download
 
 ...

 * Included libraries:
 *   DataTables 2.0.2, Buttons 3.0.1, Column visibility 3.0.1, HTML5 export 3.0.1, Select 2.0.0
 ```

When updating, check the diff and ensure that everything is present.


datatables.button.download.js was downloaded separately.